Module Response

Module Response 

Response

This module handles creating and sending HTTP responses.

Structs

HttpResponse
This is the main struct that creates a Response object. And it also handles sending responses.

Functions

create_response
Creates a new response object for JSON and TEXT type responses.
send_file
Create a new response object for file type responses.