Response
This module handles creating and sending HTTP responses.
Structs
- Http
Response - This is the main struct that creates a Response object. And it also handles sending responses.
Functions
- create_
response - Creates a new response object for JSON and TEXT type responses.
- send_
file - Create a new response object for file type responses.